@@ -17,27 +17,26 @@
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
+ *
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
+#include "config.h"
 
 #include <stdlib.h>
 
 #include <glib.h>
-#include <girepository/girepository.h>
+#include <girepository.h>
 #include <testing-util.h>
 
 #include "testing.h"
 
 void
-testing_init (gint    *argc,
-              gchar ***argv)
+testing_init (int    *argc,
+              char ***argv)
 {
   GError *error = NULL;
   static gboolean initialized = FALSE;
-  GIRepository *repository;
 
   if (initialized)
     return;
@@ -49,12 +48,10 @@ testing_init (gint    *argc,
   /* Must be after g_test_init() changes the log settings*/
   testing_util_init ();
 
-  repository = gi_repository_dup_default ();
-  gi_repository_require_private (repository,
+  g_irepository_require_private (g_irepository_get_default (),
                                  BUILDDIR "/tests/libpeas/introspection",
-                                 "Introspection", "1.0", 0, &error);
+                                 "Introspection", API_VERSION_S, 0, &error);
   g_assert_no_error (error);
-  g_clear_object (&repository);
 
   initialized = TRUE;
 }
